<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://www.facturante.com
 * @since      1.0.0
 *
 * @package    Woo_Facturante
 * @subpackage Woo_Facturante/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Woo_Facturante
 * @subpackage Woo_Facturante/admin
 * @author     Facturante
 */
 
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Woo_Facturante_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	private $soap_url;
	
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->soap_url = 'http://testing.facturante.com/api/Comprobantes.svc?wsdl';
		//$this->soap_url = 'http://www.facturante.com/api/comprobantes.svc?wsdl';

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
		/*wp_enqueue_style( 'bootstrap' , plugin_dir_url( __FILE__ ) . 'css/bootstrap.min.css');*/
		wp_enqueue_style( 'modal-fac' , plugin_dir_url( __FILE__ ) . 'css/woo-facturante-modal.css');
		wp_enqueue_style( 'load-fa', 'https://use.fontawesome.com/releases/v5.3.1/css/all.css' );
		wp_enqueue_style( $this->plugin_name , plugin_dir_url( __FILE__ ) . 'css/woo-facturante-admin.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
		/*wp_enqueue_script( 'bootstrap', plugin_dir_url( __FILE__ ) . 'js/bootstrap.min.js', array( 'jquery' ), false , true );*/
		wp_enqueue_script( 'modal-fac', plugin_dir_url( __FILE__ ) . 'js/fac-modalbootstrap.js',array( 'jquery' ), false , true );
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/woo-facturante-admin.js', array( 'jquery' ), $this->version.'2', false );
		wp_localize_script($this->plugin_name, 'fyFacturanteAdminVars', array('facturanteUrl' => plugin_dir_url(__FILE__ ) ));
	}


}