<?php

require_once dirname(__DIR__). '/sdk/WoocommerceFacturanteParser/WoocommerceFacturanteStatesMapper/WoocommerceFacturanteStatesMapper.php';

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Facturante
 * @subpackage woo-facturante/includes
 * @author     Facturante
 */
 
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

 
class Woo_Facturante {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Plugin_Name_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		$this->plugin_name = 'WooCommerce Facturante';
		
		$this->version = '1.0.0';

		$this->load_dependencies();
		
		$this->set_locale();
		
		$this->define_admin_hooks();
		

		$this->define_public_hooks();

		
		add_action('woocommerce_api_'.strtolower(get_class($this)), array(&$this, 'handle_wh_callback'));
		
	}

	

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Woo_Facturante_Loader. Orchestrates the hooks of the plugin.
	 * - Woo_Facturante_i18n. Defines internationalization functionality.
	 * - Woo_Facturante_Admin. Defines all hooks for the admin area.
	 * - Woo_Facturante_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-woo-facturante-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-woo-facturante-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-woo-facturante-admin.php';

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/Actions/Settings.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/Actions/Invoice.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/Actions/Iva.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/Actions/IvaShipping.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/Actions/Order.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/Actions/Dni.php';
		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		//require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-plugin-name-public.php';

		$this->loader = new Woo_Facturante_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Plugin_Name_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Woo_Facturante_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		//clase base del plugin
		$plugin_admin = new Woo_Facturante_Admin( $this->get_plugin_name(), $this->get_version() );
		//cargar script en la parte del panel de administracion
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );		
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->defineSettings();
		
		$this->defineFields();

		$this->defineInvoiceActions();

		$this->defineOrders();

		$this->defineIva();
		$this->defineIvaForShipping();
		
					
	}


	public function defineSettings(){
		$settings = new Settings();  
		
		$this->loader->add_filter( 'woocommerce_settings_tabs_array', $settings, 'add_settings_tab',50 );
		
		$this->loader->add_action( 'woocommerce_settings_tabs_settings_tab_woo_facturante',$settings,'settings_tab' );
		
		$this->loader->add_action( 'woocommerce_update_options_settings_tab_woo_facturante',$settings,'update_settings' );
		
	}

	public function defineFields(){
		
		$DNI = new Dni();

		$this->loader->add_action( 'woocommerce_created_customer' ,$DNI, 'woo_facturante_save_DNI' );
		
		$this->loader->add_action( 'woocommerce_edit_account_form',$DNI, 'woo_facturante_add_dni_field_to_my_account');
		
		$this->loader->add_action( 'woocommerce_save_account_details',$DNI, 'woo_facturante_save_DNI' );
		
		$this->loader->add_action( 'woocommerce_checkout_fields' ,$DNI, 'woo_facturante_dni_checkout_field' );

		$this->loader->add_filter( 'woocommerce_registration_errors',$DNI, 'woo_facturante_validate_extra_register_fields' );

		$this->loader->add_action( 'woocommerce_admin_order_data_after_billing_address', $DNI, 'woo_facturante_display_admin_order_meta');

		$this->loader->add_action( 'woocommerce_checkout_update_order_meta', $DNI, 'woo_facturante_update_order_meta' );

		$this->loader->add_action( 'woocommerce_checkout_process', $DNI, 'woo_facturante_checkout_field_process' );

		$this->loader->add_action( 'woocommerce_register_form_start',$DNI, 'woo_facturante_add_dni_field_to_register' );	
	
		$this->loader->add_filter( 'woocommerce_email_order_meta_keys', $DNI, 'woo_facturante_display_dni_in_email_fields' ); 

		$this->loader->add_action( 'woocommerce_process_shop_order_meta', $DNI, 'save_facturante_doc_and_type');


	}

    public function defineInvoiceActions(){

		$Invoice = new Invoice();

		$this->loader->add_action( 'wp_ajax_woo_facturante_do_ajax_request', $Invoice, 'woo_facturante_invoice' );

		$this->loader->add_action( 'wp_ajax_woo_facturante_do_ajax_request_nc', $Invoice, 'woo_facturante_creditNote' );
		
		$this->loader->add_action( 'wp_ajax_woo_facturante_view_ajax_request', $Invoice, 'woo_facturante_view_invoice' );

		$this->loader->add_action( 'wp_ajax_woo_facturante_view_nc_ajax_request', $Invoice, 'woo_facturante_view_nc' );

		$this->loader->add_action( 'woocommerce_order_status_changed', $Invoice, 'woo_facturante_test_automatic',10,4 );
		
		$this->loader->add_action( 'woocommerce_order_status_changed', $Invoice, 'woo_facturante_automatic_nc',10,4 );

	}

	public function defineOrders(){
		$Orders = new Order();
		
		$this->loader->add_filter( 'manage_edit-shop_order_columns', $Orders, 'facturante_buttons_column'); 

		$this->loader->add_filter( 'woocommerce_admin_order_actions',  $Orders, 'woo_facturante_order_actions',10,2 );

		$this->loader->add_action( 'manage_shop_order_posts_custom_column', $Orders, 'facturante_content_column' );
	}

	public function defineIva(){
		$IVA = new Iva();
		$this->loader->add_action ( 'woocommerce_product_options_general_product_data',$IVA , 'iva_field' );
		$this->loader->add_action( 'woocommerce_process_product_meta',$IVA , 'save_iva_field' );
	
		//add_action( 'woocommerce_variation_options', 'mytheme_woo_add_custom_variation_fields', 10, 3 )
	}

	public function defineIvaForShipping(){
		$ivashipping = new IvaShipping();
		$this->loader->add_action( 'woocommerce_shipping_zone_loaded',$ivashipping, 'add_extra_fields_in_shipping_methods');	
		$this->loader->add_action( 'woocommerce_shipping_zone_add_method',$ivashipping, 'add_extra_fields_in_shipping_methods');	
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		//$plugin_public = new Plugin_Name_Public( $this->get_plugin_name(), $this->get_version() );

		//$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		//$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		
		$this->loader->run();
	
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		
		return $this->plugin_name;
	
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Plugin_Name_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		
		return $this->loader;
	
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		
		return $this->version;
	
	}
	
	public function handle_wh_callback(){

		$server_output = trim(file_get_contents('php://input'));
		$server_output = preg_replace('/(<\?xml[^?]+?)utf-16/i', '$1utf-8', $server_output);   
		
		$xmlResponse = simplexml_load_string($server_output);
		libxml_use_internal_errors(true);

		if (false === $xmlResponse) {
			$errors = libxml_get_errors();
			echo 'Error al parsear xml'.var_export($errors, true);
			exit;
		}
		else	
		{
			
			$idComprobante =  $xmlResponse->IdComprobante;
			$estadoComprobante = $xmlResponse->EstadoComprobante;
			
			global $wpdb;
			$tbl = $wpdb->prefix.'postmeta';
			$prepare_guery = $wpdb->prepare( "SELECT post_id FROM $tbl where meta_key ='_invoice_id' and meta_value =  $idComprobante");
			
			$get_values = $wpdb->get_col( $prepare_guery );
			
			if(isset($get_values[0])){
				$order_id = $get_values[0];
				$WoocommerceFacturanteStatesMapper = new WoocommerceFacturanteStatesMapper();
				$wpState = $WoocommerceFacturanteStatesMapper->map($estadoComprobante);
				update_post_meta( $order_id, '_estado_facturante', $wpState );	
				if($wpState == WoocommerceStates::OK){
					update_post_meta($order_id,'_pdf_facturante', (string)$xmlResponse->URLPDF);
				}
				echo "Se actualizo el estado de la orden $order_id";	
				exit;
			}
			//no es una invoice, voy a buscar la creditNote
			$prepare_guery = $wpdb->prepare( "SELECT post_id FROM $tbl where meta_key ='_nc_id' and meta_value =  $idComprobante");
			
			$get_values = $wpdb->get_col( $prepare_guery );
			
			if(isset($get_values[0])){
				$order_id = $get_values[0];
				$WoocommerceFacturanteStatesMapper = new WoocommerceFacturanteStatesMapper();
				$wpState = $WoocommerceFacturanteStatesMapper->map($estadoComprobante);
				update_post_meta( $order_id, '_estado_facturante_nc', $wpState );	
				if($wpState == WoocommerceStates::OK){
					update_post_meta($order_id,'_pdf_facturante', (string)$xmlResponse->URLPDF);
				}
				echo "Se actualizo el estado de la orden $order_id";	
				exit;
			}

			echo "Error al tratar de encontrar la orden";
			exit;
		}
	}

}