<?php
define('FACTURANTE_ENDPOINT_TEST', 'http://testing.facturante.com/api/Comprobantes.svc?wsdl');
define('FACTURANTE_ENDPOINT_PROD', 'http://www.facturante.com/api/comprobantes.svc?singlewsdl');
define('FACTURANTE_ENDPOINT_TEST_REST', 'http://testing.facturante.com/woocommerce/CreditNoteFrom');
define('FACTURANTE_ENDPOINT_PROD_REST', 'http://www.facturante.com/awoocommerce/CreditNoteFrom');
define('FACTURANTE_ENDPOINT_REST_AUTH_HEADER', '38Ct7z7Q5B5F3E0143NCS52710q5MzFc3mLK5TI8Zv6OE31ZPT9Jv1pX4OFL0r83wVc1a37mvfF6nPv3Icr0goh6CRDhry6T44oX');

require_once dirname(__FILE__).'/domain/Model/Auth.php';
require_once dirname(__FILE__).'/domain/Request/ReceiptRequestModel.php';
require_once dirname(__FILE__).'/domain/Request/ViewInvoiceRequestModel.php';
require_once dirname(__FILE__).'/domain/Request/ListReceiptsRequestModel.php';
require_once dirname(__FILE__).'/domain/Response/ViewInvoiceResponseModel.php';
require_once dirname(__FILE__).'/domain/Response/ReceiptResponseModel.php';
require_once dirname(__FILE__).'/domain/Response/ErrorResponseModel.php';
require_once dirname(__FILE__).'/domain/Request/ResendInvoiceRequestModel.php';
require_once dirname(__FILE__).'/domain/Response/ResendInvoiceResponseModel.php';
require_once dirname(__FILE__).'/domain/DTO/ResponseType.php';

class FacturanteSDK {
    /**
     * The soap client to make the request to facturante.
     *
     * @var [SoapClient]
     */
    private $soapClient;
    private $auth;
    private $endpointRest;
    

    /*
    GENERA UNA INSTANCIA FACTURANTESDK
        $authData = ["Empresa" => "{empresa}","Hash" => "{Hash}","Usuario" => "{Usuario}"];
    */
    public function __construct($authData,$production = true ) {
        $this->endpointRest = $production ? FACTURANTE_ENDPOINT_PROD_REST : FACTURANTE_ENDPOINT_TEST_REST ;
        $url =  $production ? FACTURANTE_ENDPOINT_PROD : FACTURANTE_ENDPOINT_TEST ; 
        $this->soapClient = new \SoapClient($url);
        $this->auth = new Auth($authData);
    }

    /*
    GENERA UN COMPROBANTE A PARTIR DE LOS DATOS DEL CLIENTE; ENCABEZADO E ITEMS;
        {client},{header},{items}
    */ 
    public function generateFullReceipt($client,$header,$items,$responseType=ResponseType::ARRAY_TYPE) {
        try{
            $receiptRequestModel = new ReceiptRequestModel($client,$header,$items);
            $soapresponse = $this->soapClient->CrearComprobanteFull($receiptRequestModel->getRequest($this->auth));       
            $responsemodel = new ReceiptResponseModel($soapresponse);
            return $responsemodel->getResponse($responseType);
        }
        catch(\Exception $e){
            return (new ErrorResponseModel($e))->getResponse($responseType);
        }
    }

    /*
    VISUALIZA UN COMPROBANTE A PARTIR DE UN ID DE COMPROBANTE
        $data = ['id_comprobante'=>{id_comprobante}]
    */
    public function viewInvoice($data,$responseType=ResponseType::ARRAY_TYPE){
        try{
            $viewInvoiceRequestModel = new ViewInvoiceRequestModel($data);
            $soapresponse = $this->soapClient->DetalleComprobante($viewInvoiceRequestModel->getRequest($this->auth));       
            $responsemodel = new ViewInvoiceResponseModel($soapresponse);
            return $responsemodel->getResponse($responseType);
        }
        catch(\Exception $e){
            return (new ErrorResponseModel($e))->getResponse($responseType);
        }
    }

    /*
    REENVIA UN COMPROBANTE A PARTIR DE UN ID DE COMPROBANTE
        $resendInvoice
    */
    public function resendInvoiceReceipt($resendInvoice,$responseType=ResponseType::ARRAY_TYPE){
        try{
            $resendInvoiceequestModel = new ResendInvoiceRequestModel($resendInvoice);
            $soapresponse = $this->soapClient->ReenviarComprobante($resendInvoiceequestModel->getRequest($this->auth));       
            $responsemodel = new ResendInvoiceResponseModel($soapresponse);
            return $responsemodel->getResponse($responseType);
        }
        catch(\Exception $e){
            return (new ErrorResponseModel($e))->getResponse($responseType);
        }
    }


    public function createCreditNote($invoiceId){
		$ch = curl_init($this->endpointRest);
		$payload = json_encode(array(
			'idInvoice'=> $invoiceId,
            'autenticacion'=> $this->auth->getData()
		));
		curl_setopt($ch, CURLOPT_POSTFIELDS, $payload);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-Type:application/json','Facturante-Woo:' . FACTURANTE_ENDPOINT_REST_AUTH_HEADER));
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		$result = curl_exec($ch);
        curl_close($ch);
        return json_decode( $result, true );
    }

    /*
    LISTA TODOS LOS COMPROBANTES ASOCIADOS A UNA EMPRESA (pagina de a 50)
        $data = ['fecha_desde'=>{datetime},'fecha_hasta'=>{datetime},'nro_pagina'=>{nro_pagina}]
    */
    /*public function listReceipts($data){
        try{
            $ListReceiptsRequestModel = new ListReceiptsRequestModel($data);
            return $this->soapClient->ListadoComprobantes($ListReceiptsRequestModel->getRequest($this->auth));   
        }
        catch(\Exception $e){
            echo (new ErrorResponseModel($e))->getJsonResponse();
        }  
    }*/
}

?>