<?php

//namespace WoocommerceSoapParser;

require_once dirname(__DIR__). '/domain/Model/Client.php';
require_once dirname(__DIR__). '/domain/Model/Header.php';
require_once dirname(__DIR__). '/domain/Model/Item.php';
require_once dirname(__DIR__,2).'/admin/Actions/Provincias.php';
require_once dirname(__FILE__).'/WoocommerceFacturanteStatesMapper/WoocommerceFacturanteStatesMapper.php';
require_once dirname(__FILE__).'/WoocommerceFacturanteStatesMapper/MapperInterface.php';



class WoocommerceFacturanteParser {

	private $order;
	private $order_meta;
	private $mapper;

    public function __construct($order, $order_meta ) {
		$this->order = $order;
		$this->order_meta = $order_meta; 
		$this->mapper= new WoocommerceFacturanteStatesMapper();
    }

    private function getShippingMethods($shipping_data, &$total ) {
        $shipping_methods = [];

		if(is_array($shipping_data)):
			
			foreach($shipping_data as $key=>$sm){	
				
				$title = $sm->get_method_title();
				$method_id = $sm->get_method_id();
				$instance_id = $sm->get_instance_id();
				$shipping_settings = get_option( 'woocommerce_'.$method_id.'_'.$instance_id.'_settings' ); 			
				$iva = isset($shipping_settings['IVA'])?$shipping_settings['IVA']:21;
				//$sm type: WC_Order_Item_Shipping 			
				//$precio_sin_iva = round($sm->get_total()/1.21,2);
				$precio_sin_iva = $sm->get_total()/(1+($iva/100));
								
				array_push($shipping_methods, new Item(array(
					'Bonificacion' => 0,
					'Cantidad' => 1,
					'Codigo' => '',
					'GTIN'=> '7790001001085',
					'UnidadMedida'=> 1,
					'UnidadesMtx'=> 1,
					'Detalle' => "$title",
					'Gravado' => true,
					'IVA' => $iva,
					'PrecioUnitario' => $precio_sin_iva
				)));
				
			}
		endif;
		return $shipping_methods;
	}

	private function getItems($shipping_methods, &$total) {
		$items = $this->order->get_items();
		$receiptItems = array();


		$useWooTaxes = count($this->order->get_taxes()) > 0 ? true : false;

		foreach( $items as $key => $item ){
			$product_id = $item['product_id'];

			if($item['variation_id'] > 0){
				$product_id = $item['variation_id'];
				$product = new WC_Product_Variation($product_id);
			}else{
				$product = new WC_Product($product_id);
			}
			
			$iva = ($product->get_meta('IVA'))!=''? floatval(str_replace(',', '.',$product->get_meta('IVA'))):21;

			$sku = $product->get_sku();
			
			if($sku == ''){
				$sku = $product_id;
			}

			$priceOfItem = $item['line_total'] / $item['qty'];
			$precio_sin_iva = $priceOfItem/(1+($iva/100)); 

			if($useWooTaxes)
				$precio_sin_iva = $priceOfItem; 
			
			array_push($receiptItems, new Item( array(
				'Bonificacion' => 0,
				'Cantidad' => $item['qty'],
				'Codigo' => $sku,
				'GTIN'=> $sku,
				'UnidadMedida'=> 1,
				'UnidadesMtx'=> 1,
				'Detalle' => $item['name'],
				'Gravado' => true,
				'IVA' => $iva,
				'PrecioUnitario' => $precio_sin_iva
			)));
			
			$total += $item['qty'] * $precio_sin_iva;		
		}


		$subtotal =$this->order->get_subtotal();
		$totalOrder = $this->order->get_total();
		$totalShipments = $this->order->get_shipping_total();
		$quotesDiscount = $this->order->get_discount_total();
		$total = 0;
		if($useWooTaxes)
				$total = $this->order->get_total_tax(); 
		$differences = $totalOrder-$totalShipments-$subtotal+$quotesDiscount-$total;
		$differences= round($differences/(1+(21/100)),10);
		

		if($differences<0)
		{
			array_push($receiptItems, new Item( array(
				'Bonificacion' => 0,
				'Cantidad' => 1,
				'Codigo' => "DISCOUNT",
				'GTIN'=> '7790001001030',
				'UnidadMedida'=> 1,
				'UnidadesMtx'=> 1,
				'Detalle' => "Descuento al IVA",
				'Gravado' => true,
				'IVA' => 21,
				'PrecioUnitario' => $differences
			)));
		}
		elseif($differences>0)
		{
			array_push($receiptItems, new Item( array(
				'Bonificacion' => 0,
				'Cantidad' => 1,
				'Codigo' => "SURCHARGE",
				'GTIN'=> '7790001001030',
				'UnidadMedida'=> 1,
				'UnidadesMtx'=> 1,
				'Detalle' => "Recargo",
				'Gravado' => true,
				'IVA' => 21,
				'PrecioUnitario' => $differences
			)));
		}
			

		if(is_array($shipping_methods) && count($shipping_methods) > 0 ){
			foreach($shipping_methods as $k=>$v){
				array_push($receiptItems,$v);
			}
		}
		return $receiptItems;
	}

	/**
	 * Convert woocommerce data in a Client Domain Object
	 *
	 * @param string $dni
	 * @param boolean $sendReciept
	 * @param integer $paymentCondition
	 * @param boolean $iva
	 * @param boolean $iibb
	 * @return Client
	 */
    public function parseClient ($dni, $sendReciept = true, $paymentCondition = 1, $iva = false, $iibb = false){
		$countrycode =  $this->order_meta['_shipping_country'][0];
		$statecode = $this->order_meta["_billing_state"][0];
		$billing_first_name = $this->order_meta["_billing_first_name"][0];
		$billing_last_name = $this->order_meta["_billing_last_name"][0];
		$billing_email = $this->order_meta["_billing_email"][0];
		$billing_postcode = $this->order_meta["_billing_postcode"][0];		
		$billing_address_1 = $this->order_meta["_billing_address_1"][0];
		$billing_address_2 =  isset($this->order_meta["_billing_address_2"][0]) ? $this->order_meta["_billing_address_2"][0] : '' ;				
		$billing_city = $this->order_meta["_billing_city"][0];
		$billing_phone = $this->order_meta["_billing_phone"][0];
		$billing_state = isset(Provincias::provincias_facturante[$statecode])?Provincias::provincias_facturante[$statecode]:'';
		$billing_type_document_facturante =  $this->order_meta["type_document_facturante"][0];

		/*Patch for DOS61*/
		if(isset($order_meta['_billing_street'])){		
			$billing_address_1 = $order_meta['_billing_street'][0].' '.$order_meta['_billing_number'][0];
			$billing_address_2 = $order_meta['_billing_floor'][0].' '.$order_meta['_billing_apartment'][0];
		}
		

		return new Client(array(
			"CodigoPostal" => $billing_postcode,
			"CondicionPago" => $paymentCondition,
			"DireccionFiscal" =>  $billing_address_1.' '.$billing_address_2,
			"MailFacturacion" => $billing_email, 
			"NroDocumento" => $dni ,
			"PercibeIVA" => $iva, ////True: Si la empresa emisora es Agente de Retención de ARBA
			"PercibeIIBB" => $iibb, ////Si la empresa emisora es Agente de Retención de IVA
			"RazonSocial" => $billing_first_name . ' ' . $billing_last_name,
			"TipoDocumento" => $billing_type_document_facturante,//DNI
			"MailContacto" => $billing_email,
			"Telefono" => $billing_phone,
			"Contacto" => $billing_first_name . ' ' . $billing_last_name,
			"EnviarComprobante" => $sendReciept,
			"Provincia" => $billing_state,
			"Localidad" => $billing_city 
		));
	}
	
	/**
	 * Convert woocommerce data in a Header Domain Object
	 *
	 * @param string $receiptType
	 * @param integer $category
	 * @param integer $saleCondiction
	 * @param boolean $sendReceipt
	 * @param integer $currency
	 * @param integer $exchangeRate
	 * @param integer $iva
	 * @param integer $iibb
	 * @param integer $internTaxes
	 * @param integer $municPerceptions
	 * @param integer $incomePerc
	 * @param integer $suusPerc
	 * @return Header
	 */
	public function parseHeader (
		$prefix,
		$saleCondiction = 1,
		$receiptType = "F",
		$category = 1,
		$sendReceipt = true, 
		$currency= 2,
		$exchangeRate = 1,
		$iva = 0,
		$iibb = 0,
	    $internTaxes = 0,
		$municPerceptions = 0,
		$incomePerc = 0,
		$suusPerc = 0) {

		$time = new DateTime;
		$today_atom = $time->format(DateTime::ATOM);

		$paymentMethodTitle = $this->order->get_payment_method_title();
		$orderId = $this->order->get_id();
		$Observaciones = "Comprobante generado por operación de WooCommerce con ID de Orden $orderId";

		return new Header(array(				
			"Bienes" => $category, /**
					
					1: Bienes
					2: Servicios
					3: Productos y Servicios.

					**/
			"CondicionVenta" => $saleCondiction,
					/**						
						1= Contado
						2= Cuenta Corriente
						3= Tarjeta de Debito
						4= Tarjeta de Credito
						5= Cheque
						6= Ticket
						7= Otro
						8= MercadoPago
						9= Cobro Digital
						10= DineroMail
						11= Decidir
						12= Todo Pago
					**/
			"EnviarComprobante" => $sendReceipt,
			"FechaHora" => $today_atom,
			"FechaServDesde" => $today_atom,
			"FechaServHasta" => $today_atom,
			"FechaVtoPago" => $today_atom,
			"Moneda" => $currency, // PESOS ARGENTINOS (2 ARS, 3 DOLAR USA)
			"Prefijo" => $prefix,
			"TipoComprobante" => $receiptType,
			"TipoDeCambio" => $exchangeRate,
			"ImporteImpuestosInternos" => $internTaxes,
            "ImportePercepcionesMunic" => $municPerceptions,					
            "ImporteIVA" => $iva,
            "ImporteIIBB" => $iibb,	
            "AlicuotaPercGanancias" => $incomePerc,	
			"AlicuotaPercSUSS" => $suusPerc,	
			"Observaciones" => $Observaciones,
			"WebHook" => array(
				'HttpHeader' => ['Name' => 'Authorization','Value'=>"TOKEN hash='".get_option( 'wc_settings_tab_woo_facturante_hash' )."'"],
				'Url' => site_url().'/?wc-api=Woo_Facturante'
			) 
		));
	}


	public function parseItems() {
		$shipping_data = $this->order->get_items('shipping');	
		$total = 0;
		$shipping_methods = $this->getShippingMethods($shipping_data, $total);
		$items = $this->getItems($shipping_methods, $total);
		
		return $items;
	}

	public function mapFacturanteToWoocommerceState($state) {
		return $this->mapper->map($state);
	}
}

?>